@@ -34,6 +34,8 @@
 #include "utils/palloc.h"
 #include "utils/memutils.h"
 #include "context/pool_session_context.h"
+#include "protocol/pool_process_query.h"
+#include "protocol/pool_pg_utils.h"
 
 typedef struct
 {
@@ -56,7 +58,7 @@ typedef struct
 	char	   *relname;
 	int			num_params;		/* num of original params (for Parse) */
 	bool		rewrite_to_params;	/* true if timestamp is rewritten to param
-									 * insread of const */
+									 * instead of const */
 	bool		rewrite;		/* has rewritten? */
 	List	   *params;			/* list of additional params */
 }			TSRewriteContext;
@@ -254,7 +256,7 @@ relcache_lookup(TSRewriteContext * ctx)
 	return (TSRel *) pool_search_relcache(ts_relcache, ctx->backend, table_name);
 }
 
-/* If timestamp valus is required then return ts_const. Otherwize make
+/* If timestamp value is required then return ts_const. Otherwize make
  * a new ParamRef, whose number member is 0 and is overwritten at last,
  * and add it into params list in context.
  */
@@ -476,7 +478,7 @@ rewrite_timestamp_walker(Node *node, void *context)
 
 
 /*
- * Get `now()' from MASTER node
+ * Get `now()' from MAIN node
  */
 static char *
 get_current_timestamp(POOL_CONNECTION_POOL * backend)
@@ -484,7 +486,7 @@ get_current_timestamp(POOL_CONNECTION_POOL * backend)
 	POOL_SELECT_RESULT *res;
 	static char timestamp[64];
 
-	do_query(MASTER(backend), "SELECT now()", &res, MAJOR(backend));
+	do_query(MAIN(backend), "SELECT now()", &res, MAJOR(backend));
 
 	if (res->numrows != 1)
 	{
@@ -935,7 +937,7 @@ rewrite_timestamp(POOL_CONNECTION_POOL * backend, Node *node,
 		/*
 		 * CREATE TABLE t1 AS SELECT now();
 		 */
-		if (IsA(c_stmt->query, SelectStmt) && c_stmt->relkind == OBJECT_TABLE)
+		if (IsA(c_stmt->query, SelectStmt) && c_stmt->objtype == OBJECT_TABLE)
 		{
 			/* rewrite params */
 			raw_expression_tree_walker(
@@ -983,7 +985,7 @@ rewrite_timestamp(POOL_CONNECTION_POOL * backend, Node *node,
 		return NULL;
 
 	/*
-	 * PREPARE or Parse: handle additinal parameters for timestamps
+	 * PREPARE or Parse: handle additional parameters for timestamps
 	 */
 	if (ctx.rewrite_to_params && message)
 	{
@@ -1101,14 +1103,14 @@ bind_rewrite_timestamp(POOL_CONNECTION_POOL * backend,
 	{
 		/*
 		 * If num_formats is 0, the original message has no parameters or the parameter formats are all text,
-		 * so we don't need additional format codes since timestamp parametes use text as its format.
+		 * so we don't need additional format codes since timestamp parameters use text as its format.
 		 */
 		num_formats_new = 0;
 	}
 	else
 	{
 		/* If num formats is 1, this means the specified format code is applied for all original parameters,
-		 * so enlarge message length to specify format codes for each of original paramters. */
+		 * so enlarge message length to specify format codes for each of original parameters. */
 		if (num_formats == 1)
 			*len += (num_org_params - 1) * sizeof(int16);
 
@@ -1225,7 +1227,7 @@ makeStringConstFromQuery(POOL_CONNECTION_POOL * backend, char *expression)
 	char	   *str;
 
 	snprintf(query, sizeof(query), "SELECT %s", expression);
-	do_query(MASTER(backend), query, &res, MAJOR(backend));
+	do_query(MAIN(backend), query, &res, MAJOR(backend));
 
 	if (res->numrows != 1)
 	{
